@@ -4,6 +4,7 @@ from copy import deepcopy
 from pathlib import Path
 
 from django.template.defaultfilters import date
+from django.core.exceptions import ObjectDoesNotExist
 from django.utils.module_loading import import_string
 from django.utils.translation import gettext_lazy as _
 from geostore import settings as geostore_settings
@@ -80,6 +81,23 @@ class CrudViewSerializer(serializers.ModelSerializer):
             'style': obj.map_style_with_default,
             'main': True
         }]
+
+        for relation in obj.layer.relations_as_origin.all():
+            layer = relation.destination
+            try:
+                related_crud_view = layer.crud_view
+                view = {
+                    'title': related_crud_view.name,
+                    'style': related_crud_view.map_style,
+                    'id_layer_vt': related_crud_view.layer.name,
+                    'main': False,
+                    'view_source': 'relation',
+                    'pk': layer.pk
+                }
+                data.append(view)
+            except ObjectDoesNotExist:
+                pass
+
         # add extra_layer styles
         for extra_layer in obj.layer.extra_geometries.all():
             # get final style
@@ -92,7 +110,9 @@ class CrudViewSerializer(serializers.ModelSerializer):
                 'title': extra_layer.title,
                 'id_layer_vt': extra_layer.name,
                 'style': style,
-                'main': False
+                'main': False,
+                'view_source': 'extra_geometry',
+                'pk': extra_layer.pk
             })
         return data
 
